@@ -28,11 +28,15 @@ class ScilabSession;
 class ScilabCompletionObject : public Cantor::CompletionObject
 {
   public:
-    ScilabCompletionObject(const QString& cmd, ScilabSession* session);
+    ScilabCompletionObject(const QString& cmd, int index, ScilabSession* session) ;
     ~ScilabCompletionObject();
 
+  protected:
+    virtual bool mayIdentifierContain(QChar c) const;
+    virtual bool mayIdentifierBeginWith(QChar c) const;
   protected slots:
     void fetchCompletions();
+    void fetchIdentifierType();
 };
 
 #endif /* _SCILABCOMPLETIONOBJECT_H */
